'******************************************************************************************
'*                                                                                        *
'*  lthermometer V1.0 by Andreas Rutenberg mit einem Open-Micro                          *
'*                                                                                        *
'*  blau blinkend = l kalt, blau leuchtend = l noch zu kalt, grn leuchtend = normaler  *
'*  Betrieb (LED geht nach 1 Minute aus), rot leuchtend = l hei,                        *
'*  rot blinkend = l sehr hei                                                           *
'*                                                                                        *
'******************************************************************************************

' --- Betriebssystem konfigurieren --------------------------------------------------------
include "om.def"                        ' Definitionen fuer Betriebssystem
RunOnErr = on                           ' bei Fehler Programm neustarten (Fehler in ERR)
PullUpA = 0                             ' Pull-Up-Widerstnde - aus
'------------------------------------------------------------------------------------------


'--- Definitionen der QT4 Ports -----------------------------------------------------------
define frei1          ad[1]             'A-Port1
define outputB      port[5]             'A-Port2 / blaue LED
define outputR      port[2]             'A-Port4 / rote LED
define outputG      port[4]             'A-Port5 / grne LED
define Sensor         ad[6]             'A-Port6 / Sensor
'------------------------------------------------------------------------------------------
'   Die Pinbelegung der
'    Open-Micro (QT4)     _____    _____
'                       |     \__/     |
'            GND     1 [  VDD      GND  ] 8    VDD = 4.6 bis 5.5 Volt
'                       |              |
'         Sensor (6) 2 [  PTA5    PTA0  ] 7 (1) n.c.
'                       |              |
'           blau (5) 3 [  PTA4    PTA1  ] 6 (2) rot
'                       |              |
'           grn (4) 4 [  PTA3    PTA2  ] 5 (3) host/run
'                       |______________|
'
'---Variablen------------------------------------------------------------------------------
define t         Byte             'Zhlervariable
define g         Byte             'Zhlervariable fr grn

'--- Initialisierung Hard und Software ----------------------------------------------------
' Es werden jetzt die drei Farben durchgeschaltet. Danach beginnt dass
' eigentliche Programm.
'--------------------
t=0                                             ' Zhlervariable auf Null setzen
g=0                                             ' Zhlervariable grn auf Null setzen
Pause 50
Initial : pause 12				' Anzeige der Farben rot bis blau
'------------------------------------------------------------------------------------------




'--- Hauptprogramm ------------------------------------------------------------------------
' Es wird nun alle 10 Sekunden der Temperatur-Sensor abgefragt. Zeiten im Unterprogramm
'--------------------
#start                                  'Programmanfang
if Sensor<=28 then                               'Anzeige - blau blinkend bei kleiner 40
     gosub blaublink
else if Sensor>=29 and Sensor<=36 then           'Anzeige - blau bei 41-70
     gosub blau
else if Sensor>=37 and Sensor<=48 then
     gosub gruen                                 'Anzeige - grn bei 71 - 105 0,6V am Sensor, nach 1 Minute verlschend
else if Sensor>=49 and Sensor<=62 then
     gosub rot                                   'Anzeige - rot bei 106 - 130
else if Sensor>=63 then
     gosub rotblink                              'Anzeige - rot blinkend bei 131 und mehr
end if
goto start                                      'zum Programmanfang
end
'------------------------------------------------------------------------------------------


'--- Rot ----------------------------------------------------------------------------------
' Es wird die rote LED leuchten
'--------------------
FUNC rot
  g=0                                           'Rcksetzen Grnzhler
  outputR = on                                  'Rot an
  outputG = off                                 'Grn aus
  outputB = off                                 'Blaus aus
  Pause 250                                     '5 Sekunden Pause
  RETURN                                        'Rcksprung ins Hauptprogramm
END FUNC
'------------------------------------------------------------------------------------------

'--- Grn ---------------------------------------------------------------------------------
' Es wird die grne LED leuchten
'--------------------
FUNC gruen
  if g<12 then gosub gruenhell                  'Abfrage Zhler grn und Verzweigung auf hell
  if g=12 then gosub gruendunkel                'oder dunkel
  RETURN                                        'Rcksprung ins Hauptprogramm
END FUNC

FUNC gruenhell
  g=g+1                                         'Zhler erhhen um 1
  outputR = off                                 'Rot aus
  outputG = on                                  'Grn an
  outputB = off                                 'Blau aus
  Pause 250                                     '5 Sekunden Pause
  RETURN                                        'Rcksprung in FUNC gruen
END FUNC

FUNC gruendunkel
  t=0                                           'Zhlervariable auf Null setzen
  #schleife1
  t=t+1                                         'Zhler erhhen um 1
  outputR = off                                 'Rot aus
  outputG = off                                 'Grn aus
  outputB = off                                 'Blau aus
  Pause 250                                     '5 Sekunden Pause
  if t=3 then schleifeend1                      'Nach drei Umlufen beende Unterprogramm (entspricht ca. fnfzehn Sekunden)
  goto schleife1                                'Rcksprung zum Zhler erhhen
  #schleifeend1
  RETURN                                        'Rcksprung in FUNC gruen
END FUNC

'------------------------------------------------------------------------------------------

'--- Blau ---------------------------------------------------------------------------------
' Es wird die blaue LED leuchten
'--------------------
FUNC blau
  g=0                                           'Rcksetzen Grnzhler
  outputR = off                                 'Rot aus
  outputG = off                                 'Grn aus
  outputB = on                                  'Blau an
  Pause 250                                     '5 Sekunden Pause
  RETURN                                        'Rcksprung ins Hauptprogramm
END FUNC
'------------------------------------------------------------------------------------------


'--- Rot blinken --------------------------------------------------------------------------
' Es wird die rote LED blinken
'--------------------
FUNC rotblink
  g=0                                           'Rcksetzen Grnzhler
  t=0                                           'Zhlervariable auf Null setzen
  #schleife1
  t=t+1                                         'Zhler erhhen um 1
  outputR = on                                  'Rot an
  outputG = off                                 'Grn aus
  outputB = off                                 'Blau aus
  Pause 30                                      '0,6 Sekunden Pause
  outputR = off                                 'Rot aus
  Pause 30                                      '0,6 Sekunden Pause
  if t=8 then schleifeend1                      'Nach acht Umlufen beende Unterprogramm (entspricht ca. zehn Sekunden)
  goto schleife1                                'Rcksprung zum Zhler erhhen
  #schleifeend1
  RETURN                                        'Rcksprung ins Hauptprogramm
END FUNC
'------------------------------------------------------------------------------------------


'--- Blau blinken -------------------------------------------------------------------------
' Es wird die blaue LED blinken
'--------------------
FUNC blaublink
  g=0                                           'Rcksetzen Grnzhler
  t=0                                           'Zhlervariable auf Null setzen
  #schleife2
  t=t+1                                         'Zhler erhhen um 1
  outputR = off                                 'Rot aus
  outputG = off                                 'Grn aus
  outputB = on                                  'Blau an
  Pause 50                                      '1 Sekunde Pause
  outputB = off                                 'Blau aus
  Pause 50                                      '1 Sekunde Pause
  if t=5 then schleifeend2                      'Nach fnf Umlufen beende Unterprogramm (entspricht zehn Sekunden)
  goto schleife2                                'Rcksprung zum Zhler erhhen
  #schleifeend2
  RETURN                                        'Rcksprung ins Hauptprogramm
END FUNC
'------------------------------------------------------------------------------------------

'---Initialisierung------------------------------------------------------------------------
' nacheinander rot, grn, blau
'-------------------
FUNC Initial
  outputR = off					'BCD Pin-A = aus
  outputG = off					'BCD Pin-B = aus
  outputB = off					'BCD Pin-C = aus
  outputR = on                                  'rot ein
  Pause 30                                      '0,6 Sekunden Pause
  outputG = on                                  'grn ein
  Pause 30                                      '0,6 Sekunden Pause
  outputR = off                                 'rot aus
  Pause 30                                      '0,6 Sekunden Pause
  outputB = on                                  'blau ein
  Pause 30                                      '0,6 Sekunden Pause
  outputG = off                                 'grn aus
  Pause 30                                      '0,6 Sekunden Pause
  outputB = off                                 'blau aus
  Pause 30                                      '0,6 Sekunden Pause
  RETURN                                        'Rcksprung ins Hauptprogramm
End FUNC
'------------------------------------------------------------------------------------------

End                                              'Progammende

'10mV je Grad Temperaturnderung beim LM35AH maximal 2 Volt Ausgang